import {
  getSourceLocation,
  getSourceLocationByPrecedingPattern,
  getStack
} from "./chunk-RTRZYDEE.js";
import {
  useLevelFilter,
  useNamespaceFilter
} from "./chunk-UJR57SSR.js";
import {
  LogLevelError,
  LogLevelInfo,
  LogLevelWarn
} from "./chunk-YX6CL4KH.js";
import {
  formatMilliseconds,
  getTimestamp
} from "./chunk-ZFRTRIT4.js";
import {
  renderMessages,
  valueToBoolean
} from "./chunk-N5R4OMJA.js";

// src/node/log/log-node.ts
import tty from "node:tty";
import process from "node:process";
function shouldUseColor() {
  try {
    return valueToBoolean(process.env.ZEED_COLOR, tty.isatty(process.stdout.fd));
  } catch (err) {
  }
  return false;
}
var defaultUseColor;
var colors = [6, 2, 3, 4, 5, 1];
function nodeSelectColorByName(namespace) {
  let hash = 0;
  for (let i = 0; i < namespace.length; i++) {
    hash = (hash << 5) - hash + namespace.charCodeAt(i);
    hash |= 0;
  }
  return colors[Math.abs(hash) % colors.length];
}
var namespaces = {};
var startTime;
function log(...args) {
  process.stdout.write(`${renderMessages(args)}
`);
}
var TTY_STYLE = {
  BOLD: "\x1B[1m",
  UNBOLD: "\x1B[2m",
  RED: "\x1B[31m",
  GREEN: "\x1B[32m",
  BLUE: "\x1B[34m",
  PURPLE: "\x1B[35m",
  GRAY: "\x1B[37m",
  ORANGE: "\x1B[38;5;208m",
  UNCOLOR: "\x1B[0m"
};
var colorEnd = "\x1B[0m";
function colorString(text, colorCode) {
  const colorStart = colorCode === 8 /* ORANGE */ ? TTY_STYLE.ORANGE : `\x1B[3${colorCode < 8 ? colorCode : `8;5;${colorCode}`}m`;
  return `${colorStart}${text}${colorEnd}`;
}
function colorStringList(list, style, bold = true) {
  return list.map((value) => {
    if (typeof value !== "string")
      return value;
    let start = style;
    let end = colorEnd;
    if (bold) {
      start = `${TTY_STYLE.BOLD}${start}`;
      end = `${end}${TTY_STYLE.BOLD}`;
    }
    return `${start}${value}${end}`;
  });
}
function shouldUseStack() {
  try {
    return valueToBoolean(process.env.ZEED_STACK, false);
  } catch (err) {
  }
  return false;
}
var defaultUseStack;
var loggerStackTraceDebug = "loggerStackTraceDebug-7d38e5a9214b58d29734374cdb9521fd964d7485";
function LoggerNodeHandler(opt = {}) {
  if (defaultUseColor == null)
    defaultUseColor = shouldUseColor();
  if (defaultUseStack == null)
    defaultUseStack = shouldUseStack();
  if (startTime == null)
    startTime = getTimestamp();
  const {
    level = void 0,
    filter = void 0,
    colors: colors2 = defaultUseColor,
    levelHelper = true,
    nameBrackets = true,
    padding = 0,
    fill = 0,
    stack = defaultUseStack,
    time = true
  } = opt;
  const matchesNamespace = useNamespaceFilter(filter);
  const matchesLevel = useLevelFilter(level);
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const timeNow = getTimestamp();
    const name = msg.name || "";
    let ninfo = namespaces[name || ""];
    if (ninfo == null) {
      ninfo = {
        color: nodeSelectColorByName(name)
        // time: timeNow
      };
      namespaces[name] = ninfo;
    }
    const timeDiffString = formatMilliseconds(timeNow - startTime);
    let args;
    let displayName = nameBrackets ? `[${name}]` : name;
    if (padding > 0)
      displayName = displayName.padStart(padding, " ");
    if (fill > 0)
      displayName = displayName.padEnd(fill, " ");
    if (colors2) {
      const c = ninfo.color;
      args = [`${colorString(displayName, c)} | `];
      if (msg.level === LogLevelWarn)
        args.push(...colorStringList(msg.messages, TTY_STYLE.ORANGE));
      else if (msg.level === LogLevelError)
        args.push(...colorStringList(msg.messages, TTY_STYLE.RED));
      else
        args.push(...msg.messages);
      if (time)
        args.push(colorString(`+${timeDiffString}`, c));
    } else {
      args = [displayName, ...msg.messages];
      if (time)
        args.push(`+${timeDiffString}`);
    }
    if (msg.messages?.[0] === loggerStackTraceDebug) {
      try {
        console.log(getStack());
      } catch (err) {
      }
    }
    if (stack) {
      let line = "";
      if (typeof stack === "boolean") {
        line = getSourceLocationByPrecedingPattern(
          ["at Function.", "at null.log (", "at log ("],
          true
        );
        if (!line)
          line = getSourceLocation(0, true);
      } else {
        const depth = typeof stack === "number" ? stack : 3;
        line = getSourceLocation(depth, true);
      }
      if (line)
        args.push(colorString(`(${line})`, 7 /* GRAY */));
    }
    const sep = "|";
    const charLevel = ".";
    switch (msg.level) {
      case LogLevelInfo:
        if (levelHelper)
          args[0] = `I${sep}${charLevel}   ${args[0]}`;
        log(...args);
        break;
      case LogLevelWarn:
        if (levelHelper) {
          args[0] = (colors2 ? colorString(`W${sep}${charLevel}${charLevel}  `, 8 /* ORANGE */) : `W${sep}${charLevel}${charLevel}  `) + args[0];
        }
        log(...args);
        break;
      case LogLevelError:
        if (levelHelper) {
          args[0] = (colors2 ? colorString(`E${sep}${charLevel}${charLevel}${charLevel} `, 1 /* RED */) : `E${sep}${charLevel}${charLevel}${charLevel} `) + args[0];
        }
        log(...args);
        break;
      default:
        if (levelHelper)
          args[0] = `D${sep}    ${args[0]}`;
        log(...args);
        break;
    }
  };
}

export {
  colorString,
  colorStringList,
  loggerStackTraceDebug,
  LoggerNodeHandler
};
//# sourceMappingURL=chunk-2YURFNCX.js.map